@@ -36,7 +36,7 @@ import time
 # Third-party imports
 # -------------------
 from datetime import datetime
-from typing import Dict, Optional
+from typing import Dict, Optional, Any
 from multi_await import multi_await  # type: ignore
 
 import aioredis
@@ -85,7 +85,7 @@ class ConnectionManager:
     async def send_personal_message(
         self,
         receiver: str,
-        message: PeerMessage,
+        message: Dict[str, Any],
     ):
         to = receiver
         if to in self.active_connections:
@@ -211,32 +211,41 @@ async def websocket_endpoint(websocket: WebSocket, uname: str):
                     if partner:
                         partner = partner.decode("utf8")
                     else:
-                        mess = {
-                            "type": "text",
-                            "from": data["from"],
-                            "message": "Could not find a partner for you",
-                            "time": time.time(),
-                            "broadcast": False,
-                            "course_name": pmess["course_name"],
-                            "div_id": pmess["div_id"],
-                        }
-                        await manager.send_personal_message(data["from"], mess)
+                        try:
+                            mess = {
+                                "type": "text",
+                                "from": data["from"],
+                                "message": "Could not find a partner for you",
+                                "time": time.time(),
+                                "broadcast": False,
+                                "course_name": data["course_name"],
+                                "div_id": data["div_id"],
+                            }
+                            await manager.send_personal_message(data["from"], mess)
+                        except KeyError:
+                            rslogger.error(
+                                f"Not enough data to construct a message: {data}"
+                            )
+
                         rslogger.error(
                             f"{os.getpid()}: Failed to find a partner for {data['from']}"
                         )
                     if partner == username:
                         await manager.send_personal_message(partner, data)
                         # log the message
-                        await create_useinfo_entry(
-                            UseinfoValidation(
-                                event="sendmessage",
-                                act=f"to:{partner}:{data['message']}",
-                                div_id=data["div_id"],
-                                course_id=data["course_name"],
-                                sid=data["from"],
-                                timestamp=datetime.utcnow(),
+                        # todo - we should not log messages that are 'control' messages
+                        # These individual control messages update partner and answer
+                        if data["type"] != "control":
+                            await create_useinfo_entry(
+                                UseinfoValidation(
+                                    event="sendmessage",
+                                    act=f"to:{partner}:{data['message']}",
+                                    div_id=data["div_id"],
+                                    course_id=data["course_name"],
+                                    sid=data["from"],
+                                    timestamp=datetime.utcnow(),
+                                )
                             )
-                        )
                     else:
                         rslogger.debug(f"{os.getpid()}: {partner=} is not {username}")
 
